@@ -15,7 +15,8 @@ if [ -f /tmp/healthy ]; then
 fi
 
 # If we can now access the traefik ping endpoint, then we're healthy
-check=$(traefik healthcheck --ping --configFile=/mnt/ddev-global-cache/traefik/.static_config.yaml 2>&1)
+# Technique from https://doc.traefik.io/traefik/operations/ping/#entrypoint
+check=$(traefik healthcheck --ping 2>&1)
 exit_code=$?
 
 if [ $exit_code -eq 0 ]; then
