@@ -340,7 +340,7 @@ func (app *DdevApp) GetHookDefaultComments() []byte {
 }
 
 // GetComposerCreateAllowedPaths gets all paths relative to the app root that are allowed to be present
-// for a given apptype when running ddev composer create
+// for a given apptype when running ddev composer create-project
 func (app *DdevApp) GetComposerCreateAllowedPaths() ([]string, error) {
 	var allowed []string
 
@@ -397,6 +397,10 @@ func (app *DdevApp) SetApptypeSettingsPaths() {
 // DetectAppType calls each apptype's detector until it finds a match,
 // or returns 'php' as a last resort.
 func (app *DdevApp) DetectAppType() string {
+	// `generic` type should not be overridden
+	if app.Type == nodeps.AppTypeGeneric {
+		return app.Type
+	}
 	var keys []string
 	for k := range appTypeMatrix {
 		keys = append(keys, k)
