@@ -90,6 +90,7 @@ func NewApp(appRoot string, includeOverrides bool) (*DdevApp, error) {
 	app.NodeJSVersion = nodeps.NodeJSDefault
 	app.WebserverType = nodeps.WebserverDefault
 	app.SetPerformanceMode(nodeps.PerformanceModeDefault)
+	app.XHProfMode = nodeps.XHProfModeDefault
 
 	app.FailOnHookFail = nodeps.FailOnHookFailDefault
 	app.FailOnHookFailGlobal = globalconfig.DdevGlobalConfig.FailOnHookFailGlobal
@@ -630,33 +631,31 @@ func (app *DdevApp) CheckCustomConfig() {
 		customConfig = true
 	}
 
-	if globalconfig.DdevGlobalConfig.IsTraefikRouter() {
-		traefikGlobalConfigPath := filepath.Join(globalconfig.GetGlobalDdevDir(), "traefik")
-		if _, err := os.Stat(traefikGlobalConfigPath); err == nil {
-			traefikGlobalFiles, err := filepath.Glob(filepath.Join(traefikGlobalConfigPath, "static_config.*.yaml"))
-			util.CheckErr(err)
-			if len(traefikGlobalFiles) > 0 {
-				printableFiles, _ := util.ArrayToReadableOutput(traefikGlobalFiles)
-				util.Warning("Using custom global Traefik configuration (use `docker logs ddev-router` for troubleshooting): %v", printableFiles)
-				customConfig = true
+	traefikGlobalConfigPath := filepath.Join(globalconfig.GetGlobalDdevDir(), "traefik")
+	if _, err := os.Stat(traefikGlobalConfigPath); err == nil {
+		traefikGlobalFiles, err := filepath.Glob(filepath.Join(traefikGlobalConfigPath, "static_config.*.yaml"))
+		util.CheckErr(err)
+		if len(traefikGlobalFiles) > 0 {
+			printableFiles, _ := util.ArrayToReadableOutput(traefikGlobalFiles)
+			util.Warning("Using custom global Traefik configuration (use `docker logs ddev-router` for troubleshooting): %v", printableFiles)
+			customConfig = true
+		}
+	}
+	traefikConfigPath := filepath.Join(ddevDir, "traefik/config")
+	if _, err := os.Stat(traefikConfigPath); err == nil {
+		traefikFiles, err := filepath.Glob(filepath.Join(traefikConfigPath, "*.yaml"))
+		util.CheckErr(err)
+		var customTraefikFiles []string
+		for _, traefikFile := range traefikFiles {
+			sigFound, _ = fileutil.FgrepStringInFile(traefikFile, nodeps.DdevFileSignature)
+			if !sigFound {
+				customTraefikFiles = append(customTraefikFiles, traefikFile)
 			}
 		}
-		traefikConfigPath := filepath.Join(ddevDir, "traefik/config")
-		if _, err := os.Stat(traefikConfigPath); err == nil {
-			traefikFiles, err := filepath.Glob(filepath.Join(traefikConfigPath, "*.yaml"))
-			util.CheckErr(err)
-			var customTraefikFiles []string
-			for _, traefikFile := range traefikFiles {
-				sigFound, _ = fileutil.FgrepStringInFile(traefikFile, nodeps.DdevFileSignature)
-				if !sigFound {
-					customTraefikFiles = append(customTraefikFiles, traefikFile)
-				}
-			}
-			if len(customTraefikFiles) > 0 {
-				printableFiles, _ := util.ArrayToReadableOutput(customTraefikFiles)
-				util.Warning("Using custom Traefik configuration (use `docker logs ddev-router` for troubleshooting): %v", printableFiles)
-				customConfig = true
-			}
+		if len(customTraefikFiles) > 0 {
+			printableFiles, _ := util.ArrayToReadableOutput(customTraefikFiles)
+			util.Warning("Using custom Traefik configuration (use `docker logs ddev-router` for troubleshooting): %v", printableFiles)
+			customConfig = true
 		}
 	}
 
@@ -739,6 +738,17 @@ func (app *DdevApp) CheckCustomConfig() {
 		}
 	}
 
+	configPath := filepath.Join(ddevDir, "")
+	if _, err := os.Stat(configPath); err == nil {
+		configFiles, err := filepath.Glob(filepath.Join(configPath, "config.*.y*ml"))
+		util.CheckErr(err)
+		if len(configFiles) > 0 {
+			printableFiles, _ := util.ArrayToReadableOutput(configFiles)
+			util.Warning("Using custom config.*.yaml configuration: %v", printableFiles)
+			customConfig = true
+		}
+	}
+
 	if customConfig {
 		util.Warning("Custom configuration is updated on restart.\nIf you don't see your custom configuration taking effect, run 'ddev restart'.")
 	}
@@ -753,7 +763,7 @@ func (app *DdevApp) CheckDeprecations() {
 // FixObsolete removes files that may be obsolete, etc.
 func (app *DdevApp) FixObsolete() {
 	// Remove old in-project commands (which have been moved to global)
-	for _, command := range []string{"db/mysql", "host/launch", "web/xdebug"} {
+	for _, command := range []string{"db/mysql", "host/launch", "host/xhgui", "web/xdebug"} {
 		cmdPath := app.GetConfigPath(filepath.Join("commands", command))
 		signatureFound, err := fileutil.FgrepStringInFile(cmdPath, nodeps.DdevFileSignature)
 		if err == nil && signatureFound {
@@ -774,11 +784,13 @@ func (app *DdevApp) FixObsolete() {
 	}
 
 	// Remove old global commands
-	for _, command := range []string{"host/yarn"} {
+	for _, command := range []string{"host/yarn", "host/xhgui"} {
 		cmdPath := filepath.Join(globalconfig.GetGlobalDdevDir(), "commands/", command)
-		if _, err := os.Stat(cmdPath); err == nil {
-			err1 := os.Remove(cmdPath)
-			if err1 != nil {
+		// TODO: Consider checking for #ddev-generated
+		signatureFound, err := fileutil.FgrepStringInFile(cmdPath, nodeps.DdevFileSignature)
+		if err == nil && signatureFound {
+			err = os.Remove(cmdPath)
+			if err != nil {
 				util.Warning("attempted to remove %s but failed, you may want to remove it manually: %v", cmdPath, err)
 			}
 		}
@@ -820,6 +832,22 @@ func (app *DdevApp) FixObsolete() {
 			util.Warning("attempted to remove %s but failed, you may want to remove it manually: %v", legacyCommandDir, err)
 		}
 	}
+
+	addOns := GetInstalledAddonNames(app)
+	if slices.Contains(addOns, "xhgui") {
+		util.Warning("The xhgui add-on is no longer necessary with this version of DDEV, removing it.")
+		err := RemoveAddon(app, "xhgui", nil, util.FindBashPath(), false, true)
+		if err != nil {
+			util.Warning("Error removing xhgui add-on: %v", err)
+		}
+		// Reload the hooks because we don't want to run the deleted hooks
+		appCopy, err := NewApp(app.AppRoot, true)
+		if err != nil {
+			util.Warning("Error reloading app hooks after removing xhgui add-on: %v", err)
+		} else {
+			app.Hooks = appCopy.Hooks
+		}
+	}
 }
 
 type composeYAMLVars struct {
@@ -886,6 +914,12 @@ type composeYAMLVars struct {
 	WebExtraExposedPorts            string
 	BitnamiVolumeDir                string
 	UseHardenedImages               bool
+	XHGuiHTTPPort                   string
+	XHGuiHTTPSPort                  string
+	XHGuiPort                       string
+	HostXHGuiPort                   string
+	XhguiImage                      string
+	XHProfMode                      types.XHProfMode
 }
 
 // RenderComposeYAML renders the contents of .ddev/.ddev-docker-compose*.
@@ -981,6 +1015,13 @@ func (app *DdevApp) RenderComposeYAML() (string, error) {
 		// Default max time we wait for containers to be healthy
 		DefaultContainerTimeout: app.DefaultContainerTimeout,
 		StartScriptTimeout:      app.GetStartScriptTimeout(),
+		XHGuiHTTPPort:           app.GetXHGuiHTTPPort(),
+		XHGuiHTTPSPort:          app.GetXHGuiHTTPSPort(),
+		XHGuiPort:               GetInternalPort(app, "xhgui"),
+		HostXHGuiPort:           app.HostXHGuiPort,
+		XhguiImage:              docker.GetXhguiImage(),
+		XHProfMode:              app.GetXHProfMode(),
+
 		// Only use the extra_hosts technique for Linux and only if not WSL2 and not Colima
 		// If WSL2 we have to figure out other things, see GetHostDockerInternalIP()
 		UseHostDockerInternalExtraHosts: (runtime.GOOS == "linux" && !nodeps.IsWSL2() && !dockerutil.IsColima()) || (nodeps.IsWSL2() && globalconfig.DdevGlobalConfig.XdebugIDELocation == globalconfig.XdebugIDELocationWSL2),
