@@ -112,6 +112,7 @@ func Cleanup(app *DdevApp) error {
 	if fileutil.FileExists(app.DockerComposeFullRenderedYAMLPath()) {
 		_, _, err := dockerutil.ComposeCmd(&dockerutil.ComposeCmdOpts{
 			ComposeFiles: []string{app.DockerComposeFullRenderedYAMLPath()},
+			Profiles:     []string{`*`},
 			Action:       []string{"down"},
 		})
 		if err != nil {
@@ -512,9 +513,6 @@ func (app *DdevApp) GetRelativeWorkingDirectory() string {
 func (app *DdevApp) HasCustomCert() bool {
 	customCertsPath := app.GetConfigPath("custom_certs")
 	certFileName := fmt.Sprintf("%s.crt", app.Name)
-	if !globalconfig.DdevGlobalConfig.IsTraefikRouter() {
-		certFileName = fmt.Sprintf("%s.crt", app.GetHostname())
-	}
 	return fileutil.FileExists(filepath.Join(customCertsPath, certFileName))
 }
 
