@@ -45,5 +45,10 @@ func GetSSHAuthImage() string {
 
 // GetRouterImage returns the router image:tag reference
 func GetRouterImage() string {
-	return versionconstants.TraefikRouterImage
+	return fmt.Sprintf("%s:%s", versionconstants.TraefikRouterImage, versionconstants.TraefikRouterTag)
+}
+
+// GetXhguiImage returns the xhgui image:tag reference
+func GetXhguiImage() string {
+	return fmt.Sprintf("%s:%s", versionconstants.XhguiImage, versionconstants.XhguiTag)
 }
