@@ -65,6 +65,8 @@ type GlobalConfig struct {
 	RouterHTTPSPort                  string                      `yaml:"router_https_port"`
 	RouterMailpitHTTPPort            string                      `yaml:"mailpit_http_port,omitempty"`
 	RouterMailpitHTTPSPort           string                      `yaml:"mailpit_https_port,omitempty"`
+	RouterXHGuiHTTPPort              string                      `yaml:"xhgui_http_port,omitempty"`
+	RouterXHGuiHTTPSPort             string                      `yaml:"xhgui_https_port,omitempty"`
 	SimpleFormatting                 bool                        `yaml:"simple_formatting"`
 	TableStyle                       string                      `yaml:"table_style"`
 	TraefikMonitorPort               string                      `yaml:"traefik_monitor_port,omitempty"`
@@ -75,6 +77,7 @@ type GlobalConfig struct {
 	WSL2NoWindowsHostsMgt    bool                    `yaml:"wsl2_no_windows_hosts_mgt"`
 	WebEnvironment           []string                `yaml:"web_environment"`
 	XdebugIDELocation        string                  `yaml:"xdebug_ide_location"`
+	XHProfMode               configTypes.XHProfMode  `yaml:"xhprof_mode,omitempty"`
 	ProjectList              map[string]*ProjectInfo `yaml:"project_info,omitempty"`
 }
 
@@ -324,6 +327,10 @@ func WriteGlobalConfig(config GlobalConfig) error {
 		cfgCopy.PerformanceMode = cfgCopy.GetPerformanceMode()
 	}
 
+	if cfgCopy.XHProfMode == configTypes.XHProfModeEmpty {
+		cfgCopy.XHProfMode = nodeps.XHProfModeDefault
+	}
+
 	// We only have one router, so this field is old, and when writing we can omitempty
 	cfgCopy.Router = ""
 
@@ -391,6 +398,10 @@ func WriteGlobalConfig(config GlobalConfig) error {
 # router_http_port: <port>  # Port to be used for http (defaults to 80)
 # router_https_port: <port> # Port for https (defaults to 443)
 
+# xhprof_mode: [prepend|xhgui]
+# Set to "xhgui" to enable XHGui features
+# "xhgui" will become default in a future major release
+
 # instrumentation_user: <your_username> # can be used to give DDEV specific info about who you are
 # developer_mode: true # (defaults to false) is not used widely at this time.
 # router_bind_all_interfaces: false  # (defaults to false)
@@ -440,6 +451,12 @@ func WriteGlobalConfig(config GlobalConfig) error {
 # Change this only if you're having conflicts with some
 # service that needs port 10999
 
+# xhgui_http_port: 8143
+# Router port used for xhgui HTTP, can be changed in case of conflicts
+
+# xhgui_https_port: 8142
+# Router port used for xhgui HTTPS, can be changed in case of conflicts
+
 # wsl2_no_windows_hosts_mgt: false
 # On WSL2 by default the Windows-side hosts file (normally C:\Windows\system32\drivers\etc\hosts)
 # is used for hosts file management, but doing that requires running sudo and ddev.exe on
@@ -520,6 +537,14 @@ func ReadProjectList() error {
 		return err
 	}
 
+	// Sanitize the project list
+	for name, project := range DdevProjectList {
+		if project == nil || project.AppRoot == "" {
+			logrus.Warningf("Project '%s' in global project list has incomplete configuration and has been ignored.", name)
+			delete(DdevProjectList, name)
+		}
+	}
+
 	// Clean up the deprecated DdevGlobalConfig.ProjectList if it not nil,
 	// but only if the new one DdevProjectList is not nil (for safe migration).
 	if DdevGlobalConfig.ProjectList != nil && DdevProjectList != nil {
@@ -849,11 +874,6 @@ func IsInternetActive() bool {
 	return active
 }
 
-// IsTraefikRouter returns true if the router is Traefik
-func (c *GlobalConfig) IsTraefikRouter() bool {
-	return c.Router == types.RouterTypeTraefik
-}
-
 // DockerComposeVersion is filled with the version we find for docker-compose
 var DockerComposeVersion = ""
 
@@ -876,9 +896,7 @@ func GetRequiredDockerComposeVersion() string {
 // GetRouterURL Return the Traefik router URL
 func GetRouterURL() string {
 	routerURL := ""
-	// Until we figure out how to configure this, use static value
-	if DdevGlobalConfig.IsTraefikRouter() {
-		routerURL = "http://127.0.0.1:" + DdevGlobalConfig.TraefikMonitorPort
-	}
+	routerURL = "http://127.0.0.1:" + DdevGlobalConfig.TraefikMonitorPort
+
 	return routerURL
 }
