@@ -11,25 +11,35 @@ var AmplitudeAPIKey = ""
 var WebImg = "ddev/ddev-webserver"
 
 // WebTag defines the default web image tag
-var WebTag = "v1.24.3" // Note that this can be overridden by make
+var WebTag = "v1.24.4" // Note that this can be overridden by make
 
 // DBImg defines the default db image used for applications.
 var DBImg = "ddev/ddev-dbserver"
 
 // BaseDBTag is the main tag, DBTag is constructed from it
-var BaseDBTag = "v1.24.3"
+var BaseDBTag = "v1.24.4"
 
-const TraefikRouterImage = "ddev/ddev-traefik-router:v1.24.3"
+// TraefikRouterImage is image for router
+var TraefikRouterImage = "ddev/ddev-traefik-router"
+
+// TraefikRouterTag is traefik router tag
+var TraefikRouterTag = "v1.24.4"
 
 // SSHAuthImage is image for agent
 var SSHAuthImage = "ddev/ddev-ssh-agent"
 
 // SSHAuthTag is ssh-agent auth tag
-var SSHAuthTag = "v1.24.3"
+var SSHAuthTag = "v1.24.4"
 
 // BusyboxImage is used a couple of places for a quick-pull
 var BusyboxImage = "busybox:stable"
 
+// XhguiImage is image for xhgui
+var XhguiImage = "ddev/ddev-xhgui"
+
+// XhguiTag is xhgui tag
+var XhguiTag = "v1.24.4"
+
 // UtilitiesImage is used in bash scripts
 var UtilitiesImage = "ddev/ddev-utilities"
 
@@ -41,4 +51,4 @@ var MutagenVersion = ""
 
 const RequiredMutagenVersion = "0.18.1"
 
-const RequiredDockerComposeVersionDefault = "v2.33.1"
+const RequiredDockerComposeVersionDefault = "v2.34.0"
